@@ -5,7 +5,7 @@ import warnings
 warnings.simplefilter("ignore")
 
 from akerbp.mlops.core import logger, config
-locals().update(config.getenv.__dict__)
+locals().update(config.getenv)
 logging=logger.get_logger()
 
 service = import_module(f"akerbp.mlops.services.{service_name}").service
