@@ -13,17 +13,18 @@ from shutil import make_archive, unpack_archive
 from cognite.client.exceptions import CogniteNotFoundError, CogniteAPIError
 
 from akerbp.mlops.core import logger, config
-locals().update(config.getenv.__dict__)
+locals().update(config.getenv)
 
 logging=logger.get_logger(name='cdf_helper')
 
 global_client = {}
-api_keys=config.api_keys.__dict__
+api_keys=config.api_keys
 
 
 def set_up_cdf_client(context='run'):
     """
-    Set up the global client used by most helpers. This needs to be called before using any helper. Should be called once with all required keys.
+    Set up the global client used by most helpers. This needs to be called
+    before using any helper. Should be called once with all required keys.
 
     Input:
       - context: string either 'run' (access to data and functions) or 'deploy'
@@ -96,7 +97,7 @@ def create_function(
         description=description,
         owner=owner,
         secrets=secrets,
-        env_vars=config.getenv.__dict__
+        env_vars=config.getenv
     )
     logging.debug(
         f"Created {function_name}: {folder=}, {handler_path=}"
