@@ -3,6 +3,7 @@ import os
 from typing import List, Optional
 from importlib import import_module
 from pydantic.dataclasses import dataclass
+from dataclasses import asdict
 
 from akerbp.mlops.core import helpers 
 from akerbp.mlops.core import logger
@@ -34,13 +35,14 @@ class EnvVar():
             raise ValueError(m)
 
 # Read environmental variables
-getenv=EnvVar(
+_getenv=EnvVar(
     env=os.getenv('ENV'), 
     service_name=os.getenv('SERVICE_NAME'), 
     local_deployment=os.getenv('LOCAL_DEPLOYMENT'),
     google_project_id=os.getenv('GOOGLE_PROJECT_ID')
 )
-
+getenv=asdict(_getenv)
+logging.debug(getenv)
 
 @dataclass
 class CdfKeys():
@@ -48,15 +50,16 @@ class CdfKeys():
     files: Optional[str]
     functions: Optional[str]
 
-api_keys = CdfKeys(
+_api_keys = CdfKeys(
    data = os.environ['COGNITE_API_KEY_DATA'],
    files = os.environ['COGNITE_API_KEY_FILES'],
    functions = os.environ['COGNITE_API_KEY_FUNCTIONS']
 )
+api_keys = asdict(_api_keys)
 
 def update_cdf_keys(new_keys):
     global api_keys
-    api_keys=CdfKeys(**new_keys)
+    api_keys=asdict(CdfKeys(**new_keys))
 
 
 @dataclass
@@ -90,7 +93,7 @@ class ModelConfig():
         from akerbp.mlops.cdf.helpers import set_up_cdf_client
         
         # Derived fields
-        if getenv.env == 'dev' and not getenv.local_deployment:
+        if _getenv.env == 'dev' and not _getenv.local_deployment:
             self.deployment_platform = 'local'
         
         if self.deployment_platform == 'cdf':
@@ -121,8 +124,8 @@ class ModelConfig():
 
     def post_model_reqs(self):
         service_test = import_module(self.test_import_path).ServiceTest()
-        self.input = getattr(service_test, f"{getenv.service_name}_input")
-        self.check = getattr(service_test, f"{getenv.service_name}_check")
+        self.input = getattr(service_test, f"{_getenv.service_name}_input")
+        self.check = getattr(service_test, f"{_getenv.service_name}_check")
 
 
 @dataclass
