@@ -11,7 +11,7 @@ from akerbp.mlops.core import logger, config
 
 logging=logger.get_logger(name='MLOps')
 
-locals().update(config.getenv.__dict__)
+locals().update(config.getenv)
 
 
 def get_version():
