@@ -14,7 +14,7 @@ import json
 
 
 from akerbp.mlops.core import config, logger 
-locals().update(config.getenv.__dict__)
+locals().update(config.getenv)
 logging=logger.get_logger(name='gc_helper')
 
 
@@ -89,8 +89,8 @@ def run_container(image_name, service_account):
     Run container with a service account
     """
     logging.info(f"Run container, {image_name=}, {service_account=}")
-    envs = config.getenv.__dict__.keys()
-    envs = [f"{env}={eval(env)}" for env in envs]
+    envs = config.getenv.keys()
+    envs = [f"{e}={eval(e)}" for e in envs]
     env_list_string=','.join(envs)
     
     subprocess.check_call(
