@@ -4,7 +4,7 @@ import os
 
 import akerbp.mlops.cdf.helpers as cdf
 from akerbp.mlops.core import config, logger
-locals().update(config.getenv.__dict__)
+locals().update(config.getenv)
 logging=logger.get_logger(name='MLOps')
 
 
